/*++++++++++++++
.IDENTIFICATION labels.h
.LANGUAGE       C
.AUTHOR         Francois Ochsenbein [CDS]
.ENVIRONMENT    Unix, CDS Catalogues
.KEYWORDS       Description of a Table
.VERSION  1.0   15-May-1991 (anafile)
.VERSION  4.0	28-Jul-1994: Create larger package
.VERSION  4.1	19-Jul-2009: D_ = Delta-value
.VERSION  4.2	20-Jun-2011: B_ = upper bound, b_ = lower bound
.VERSION  4.3	16-Mar-2012: s_ = dispersion measure
.COMMENTS       This file contains only the default limits
		for frequently used column labels.
		This file is only used by tbf_load.
---------------*/
#ifndef LABELS_DEF
#define LABELS_DEF	0

typedef struct {	/* Special labels */
    char *name;
    char *limits;	/* implied limit */
    char *unit;		/* Implied unit; "=" means 'same as dependent'  */
} LABEL;

static LABEL known_label[] = {
    { "RAds", "[0,600[",  "0.1s"},		/* Deci-seconds */
    { "RAcs", "[0,6000[", "0.01s"},		/* Centi-seconds */
    { "RAms", "[0,60000[", "ms"},		/* Milli-seconds */
    { "RAh", "[0,24[", "h"},
    { "RAm", "[0,60[", "min"},
    { "RAs", "[0,60[", "s"},
    { "DE-", "[-+]", "---"},
    { "DEds", "[0,600[", "0.1arcsec"},		/* Deci-seconds */
    { "DEcs", "[0,6000[", "10mas"},		/* Centi-seconds */
    { "DEms", "[0,60000[", "mas"},		/* Milli-seconds */
    { "DEd", "[0,89]", "deg"},
    { "DEm", "[0,60[", "arcmin"},
    { "DEs", "[0,60[", "arcsec"},
    { "RAdeg", "[0,360[", "deg"},		/* RA in decimal degrees */
    { "DEdeg", "[-90,90]", "deg"},		/* DE in decimal degrees */
    { "ELON", "[0,360[", "deg"},
    { "ELAT", "[-90,90]", "deg"},
    { "GLON", "[0,360[", "deg"},
    { "GLAT", "[-90,90]", "deg"},
    { "Diam", "[0,]"},			/* Diameter	*/
    { "Rad", "[0,]"},			/* Radius	*/
    { "Sep", "[0,]"},			/* Separation	*/
    { "PA", "[0,360[", "deg"},		/* Position Angle */
    { "2_", "[0,]", "---"}, 		/* chi-2 value	  */
    { "a_", "[0,]", "---"}, 		/* Accuracy Num.  */
    { "B_", "[*,]", "="}, 		/* Upper bound    */
    { "b_", "[,*]", "="}, 		/* Lower bound    */
    { "D_", (char *)0, "="}, 		/* Delta (O-C)    */
    { "d_", "[0,]", "---"}, 		/* Degrees Freed. */
    { "E_", "[0,]", "="}, 		/* Standard +Error*/
    { "e_", "[0,]", "="}, 		/* Standard Error */
    { "f_", (char *)0, "---"}, 		/* Flag on parm.  */
    { "L_", (char *)0, "---"}, 		/* Likelihood     */
    { "l_", "[<>]", "---"}, 		/* Limit flag     */
    { "m_", (char *)0, "---"}, 		/* Multiplicity   */
    { "n_", (char *)0, "---"}, 		/* Note on parm.  */
    { "o_", "[0,]", "---"}, 		/* Number of obs. */
    { "q_", (char *)0, "---"}, 		/* Quality on ... */
    { "r_", (char *)0, "---"}, 		/* Reference  ... */
    { "r_", (char *)0, "---"}, 		/* Reference  ... */
    { "s_", "[0,]", "="}, 		/* Dispersion (sigma) */
    { "u_", "[:]", "---"}, 		/* Uncertainty fl */
    { "w_", "[0,]", "---"}, 		/* Weight	  */
    { "x_", (char *)0, "---"}, 		/* Unit in which..*/
};
static int i2known_label = 23;		/* Where 2-byte labels start */

#endif
